@@ -17,6 +17,7 @@ static const gchar *authors[] =
 {
     "Yadickson Soto <yadickson@gmail.com>",
     "Rodolfo Granata <warlock.cc@gmail.com>",
+    "Ivan Fitenko <ivan.fitenko@eltrino.com>",
     NULL
 };
 
@@ -26,7 +27,7 @@ static const gchar *documenters[] =
     NULL
 };
 
-static const gchar * translater = "Yadickson Soto <yadickson@gmail.com>";
+static const gchar * translater = "Español - Yadickson Soto <yadickson@gmail.com>\nDeutsch - Daniel MeissWilhelm <meisssw01@googlemail.com>";
 
 static GladeXML * xml = NULL;
 static bool edit = false;
@@ -162,10 +163,10 @@ void set_comboboxs()
     gtk_list_store_set (list_store, &iter, COMBO_COLUMN_TEXT, _("center"), COMBO_COLUMN_ID, POS_CENTER, -1);
 
     gtk_list_store_append (list_store, &iter);
-    gtk_list_store_set (list_store, &iter, COMBO_COLUMN_TEXT, _("bottom-left"), COMBO_COLUMN_ID, POS_BOTTOM_LEFT, -1);
+    gtk_list_store_set (list_store, &iter, COMBO_COLUMN_TEXT, _("bot-left"), COMBO_COLUMN_ID, POS_BOTTOM_LEFT, -1);
 
     gtk_list_store_append (list_store, &iter);
-    gtk_list_store_set (list_store, &iter, COMBO_COLUMN_TEXT, _("bottom-right"), COMBO_COLUMN_ID, POS_BOTTOM_RIGHT, -1);
+    gtk_list_store_set (list_store, &iter, COMBO_COLUMN_TEXT, _("bot-right"), COMBO_COLUMN_ID, POS_BOTTOM_RIGHT, -1);
 
     gtk_list_store_append (list_store, &iter);
     gtk_list_store_set (list_store, &iter, COMBO_COLUMN_TEXT, _("top-left"), COMBO_COLUMN_ID, POS_TOP_LEFT, -1);
@@ -277,9 +278,9 @@ void set_config_states(std::string command)
 
     OptParser tmpoptparser(argc, argv);
 
-    if ( tmpoptparser.isSet( CONFIG ) )
+    if ( tmpoptparser.isSet( OptParser::CONFIG ) )
     {
-       configFile = tmpoptparser.getArg( CONFIG );
+       configFile = tmpoptparser.getArg( OptParser::CONFIG );
        Config config;
        config.setFile (configFile);
        config.getAppList ();
@@ -306,7 +307,7 @@ void set_config_states(std::string command)
             command = PACKAGE_NAME" "DEFAULT_ARGV;
         }
 
-        if (argc <= 1 || tmpoptparser.isSet( CONFIG ))
+        if (argc <= 1 || tmpoptparser.isSet( OptParser::CONFIG ))
         {
             std::list<std::string> list;
             Utils util;
@@ -332,124 +333,136 @@ void set_config_states(std::string command)
 
     OptParser opt(argc, argv);
 
-    if(opt.isSet(BPRESS))
+    if(opt.isSet(OptParser::BPRESS))
     {
         checkbutton = glade_xml_get_widget (xml, "checkbutton_bpress");
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), true);
     }
-    if(opt.isSet(ABOVE_DESK))
+    if(opt.isSet(OptParser::ABOVE_DESK))
     {
         checkbutton = glade_xml_get_widget (xml, "checkbutton_above_desk");
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), true);
     }
-    if(opt.isSet(VBAR))
+    if(opt.isSet(OptParser::VBAR))
     {
         checkbutton = glade_xml_get_widget (xml, "checkbutton_vbar");
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), true);
     }
-    if(opt.isSet(NOFONT))
+    if(opt.isSet(OptParser::NOFONT))
     {
         checkbutton = glade_xml_get_widget (xml, "checkbutton_nofont");
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), true);
     }
-    if(opt.isSet(POS))
+    if(opt.isSet(OptParser::POS))
     {
         checkbutton = glade_xml_get_widget (xml, "checkbutton_pos");
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), true);
         GtkWidget * combo = glade_xml_get_widget (xml, "combobox_pos");
 
-        std::string pos = opt.getArg(POS);
+        std::string pos = opt.getArg(OptParser::POS);
 
         if (pos == "top") gtk_combo_box_set_active (GTK_COMBO_BOX (combo), POS_TOP);
         else if (pos == "bottom") gtk_combo_box_set_active (GTK_COMBO_BOX (combo), POS_BOTTOM);
         else if (pos == "left") gtk_combo_box_set_active (GTK_COMBO_BOX (combo), POS_LEFT);
         else if (pos == "center") gtk_combo_box_set_active (GTK_COMBO_BOX (combo), POS_CENTER);
-        else if (pos == "bottom-left") gtk_combo_box_set_active (GTK_COMBO_BOX (combo), POS_BOTTOM_LEFT);
-        else if (pos == "bottom-right") gtk_combo_box_set_active (GTK_COMBO_BOX (combo), POS_BOTTOM_RIGHT);
+        else if (pos == "bot-left") gtk_combo_box_set_active (GTK_COMBO_BOX (combo), POS_BOTTOM_LEFT);
+        else if (pos == "bot-right") gtk_combo_box_set_active (GTK_COMBO_BOX (combo), POS_BOTTOM_RIGHT);
         else if (pos == "top-left") gtk_combo_box_set_active (GTK_COMBO_BOX (combo), POS_TOP_LEFT);
         else if (pos == "top-right") gtk_combo_box_set_active (GTK_COMBO_BOX (combo), POS_TOP_RIGHT);
         else /*if (pos == "right")*/ gtk_combo_box_set_active (GTK_COMBO_BOX (combo), POS_RIGHT);
     }
-    if(opt.isSet(GROW))
+    if(opt.isSet(OptParser::GROW))
     {
         checkbutton = glade_xml_get_widget (xml, "checkbutton_grow");
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), true);
     }
-    if(opt.isSet(OFFSET))
+    if(opt.isSet(OptParser::OFFSET))
     {
         checkbutton = glade_xml_get_widget (xml, "checkbutton_offset");
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), true);
         spinbutton = glade_xml_get_widget (xml, "spinbutton_offset");
-        gtk_spin_button_set_value (GTK_SPIN_BUTTON (spinbutton), atoi(opt.getArg(OFFSET).c_str()));
+        gtk_spin_button_set_value (GTK_SPIN_BUTTON (spinbutton), atoi(opt.getArg(OptParser::OFFSET).c_str()));
     }
-    if(opt.isSet(NORELOAD))
+    if(opt.isSet(OptParser::NORELOAD))
     {
         checkbutton = glade_xml_get_widget (xml, "checkbutton_noreload");
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), true);
     }
-    if(opt.isSet(ISIZE))
+    if(opt.isSet(OptParser::TASKBAR))
+    {
+        checkbutton = glade_xml_get_widget (xml, "checkbutton_taskbar");
+        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), true);
+    }
+    if(opt.isSet(OptParser::RSIZE))
+    {
+        checkbutton = glade_xml_get_widget (xml, "checkbutton_rsize");
+        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), true);
+        spinbutton = glade_xml_get_widget (xml, "spinbutton_rsize");
+        gtk_spin_button_set_value (GTK_SPIN_BUTTON (spinbutton), atoi(opt.getArg(OptParser::RSIZE).c_str()));
+    }
+    if(opt.isSet(OptParser::ISIZE))
     {
         checkbutton = glade_xml_get_widget (xml, "checkbutton_isize");
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), true);
         spinbutton = glade_xml_get_widget (xml, "spinbutton_isize");
-        gtk_spin_button_set_value (GTK_SPIN_BUTTON (spinbutton), atoi(opt.getArg(ISIZE).c_str()));
+        gtk_spin_button_set_value (GTK_SPIN_BUTTON (spinbutton), atoi(opt.getArg(OptParser::ISIZE).c_str()));
     }
-    if(opt.isSet(IDIST))
+    if(opt.isSet(OptParser::IDIST))
     {
         checkbutton = glade_xml_get_widget (xml, "checkbutton_idist");
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), true);
         spinbutton = glade_xml_get_widget (xml, "spinbutton_idist");
-        gtk_spin_button_set_value (GTK_SPIN_BUTTON (spinbutton), atoi(opt.getArg(IDIST).c_str()));
+        gtk_spin_button_set_value (GTK_SPIN_BUTTON (spinbutton), atoi(opt.getArg(OptParser::IDIST).c_str()));
     }
-    if(opt.isSet(NANIM))
+    if(opt.isSet(OptParser::NANIM))
     {
         checkbutton = glade_xml_get_widget (xml, "checkbutton_nanim");
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), true);
         spinbutton = glade_xml_get_widget (xml, "spinbutton_nanim");
-        gtk_spin_button_set_value (GTK_SPIN_BUTTON (spinbutton), atoi(opt.getArg(NANIM).c_str()));
+        gtk_spin_button_set_value (GTK_SPIN_BUTTON (spinbutton), atoi(opt.getArg(OptParser::NANIM).c_str()));
     }
-    if(opt.isSet(ZOOMF))
+    if(opt.isSet(OptParser::ZOOMF))
     {
         checkbutton = glade_xml_get_widget (xml, "checkbutton_zoomf");
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), true);
         spinbutton = glade_xml_get_widget (xml, "spinbutton_zoomf");
-        gtk_spin_button_set_value (GTK_SPIN_BUTTON (spinbutton), atof(opt.getArg(ZOOMF).c_str()));
+        gtk_spin_button_set_value (GTK_SPIN_BUTTON (spinbutton), atof(opt.getArg(OptParser::ZOOMF).c_str()));
     }
-    if(opt.isSet(JUMPF))
+    if(opt.isSet(OptParser::JUMPF))
     {
         checkbutton = glade_xml_get_widget (xml, "checkbutton_jumpf");
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), true);
         spinbutton = glade_xml_get_widget (xml, "spinbutton_jumpf");
-        gtk_spin_button_set_value (GTK_SPIN_BUTTON (spinbutton), atof(opt.getArg(JUMPF).c_str()));
+        gtk_spin_button_set_value (GTK_SPIN_BUTTON (spinbutton), atof(opt.getArg(OptParser::JUMPF).c_str()));
     }
-    if(opt.isSet(DBLCLK))
+    if(opt.isSet(OptParser::DBLCLK))
     {
         checkbutton = glade_xml_get_widget (xml, "checkbutton_dblclk");
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), true);
         spinbutton = glade_xml_get_widget (xml, "spinbutton_dblclk");
-        gtk_spin_button_set_value (GTK_SPIN_BUTTON (spinbutton), atoi(opt.getArg(DBLCLK).c_str()));
+        gtk_spin_button_set_value (GTK_SPIN_BUTTON (spinbutton), atoi(opt.getArg(OptParser::DBLCLK).c_str()));
     }
-    if(opt.isSet(BALFA))
+    if(opt.isSet(OptParser::BALFA))
     {
         checkbutton = glade_xml_get_widget (xml, "checkbutton_balfa");
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), true);
         spinbutton = glade_xml_get_widget (xml, "spinbutton_balfa");
-        gtk_spin_button_set_value (GTK_SPIN_BUTTON (spinbutton), atoi(opt.getArg(BALFA).c_str()));
+        gtk_spin_button_set_value (GTK_SPIN_BUTTON (spinbutton), atoi(opt.getArg(OptParser::BALFA).c_str()));
     }
-    if(opt.isSet(FALFA))
+    if(opt.isSet(OptParser::FALFA))
     {
         checkbutton = glade_xml_get_widget (xml, "checkbutton_falfa");
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), true);
         spinbutton = glade_xml_get_widget (xml, "spinbutton_falfa");
-        gtk_spin_button_set_value (GTK_SPIN_BUTTON (spinbutton), atoi(opt.getArg(FALFA).c_str()));
+        gtk_spin_button_set_value (GTK_SPIN_BUTTON (spinbutton), atoi(opt.getArg(OptParser::FALFA).c_str()));
     }
-    if(opt.isSet(FILTER))
+    if(opt.isSet(OptParser::FILTER))
     {
         checkbutton = glade_xml_get_widget (xml, "checkbutton_filter");
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), true);
         GtkWidget * combo = glade_xml_get_widget (xml, "combobox_filter");
 
-        std::string filter = opt.getArg(FILTER);
+        std::string filter = opt.getArg(OptParser::FILTER);
         int f;
         std::stringstream ss(filter);
         ss >> f;
@@ -460,24 +473,22 @@ void set_config_states(std::string command)
         else /*if (filter == "none")*/ gtk_combo_box_set_active (GTK_COMBO_BOX (combo), FILTER_NONE);
     }
     
-    if(opt.isSet(FC))
+    if(opt.isSet(OptParser::FC))
     {
         checkbutton = glade_xml_get_widget (xml, "checkbutton_fc");
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), true);
 
-        std::string scolor = opt.getArg(FC);
-
-        Utils util;
-        scolor = util.replace(scolor, "0x", "#");
-
-        if (scolor.length() > 7)
-            scolor = scolor.substr (0, 7);
+        std::string scolor = opt.getArg(OptParser::FC);
+        std::string salpha = scolor.substr (2, 2);
+        scolor = "#" + scolor.substr (4, 6);
 
         GdkColor rgb;
         GtkWidget * color = glade_xml_get_widget (xml, "colorbutton_fc");
 
         gdk_color_parse (scolor.c_str(), &rgb);
         gtk_color_button_set_color (GTK_COLOR_BUTTON (color), &rgb);
+        gtk_color_button_set_use_alpha (GTK_COLOR_BUTTON (color), TRUE);
+        gtk_color_button_set_alpha (GTK_COLOR_BUTTON (color), 256*(strtol ( salpha.c_str(), NULL, 16 ) + 0.5));
     }
 
     if (argc > 0) delete[] argv;
@@ -546,6 +557,10 @@ void set_signals()
     widget = glade_xml_get_widget (xml, "spinbutton_offset");
     g_signal_connect (G_OBJECT (check), "toggled", G_CALLBACK (checkbutton_toggled), widget);
 
+    check = glade_xml_get_widget (xml, "checkbutton_rsize");
+    widget = glade_xml_get_widget (xml, "spinbutton_rsize");
+    g_signal_connect (G_OBJECT (check), "toggled", G_CALLBACK (checkbutton_toggled), widget);
+
     check = glade_xml_get_widget (xml, "checkbutton_isize");
     widget = glade_xml_get_widget (xml, "spinbutton_isize");
     g_signal_connect (G_OBJECT (check), "toggled", G_CALLBACK (checkbutton_toggled), widget);
@@ -874,8 +889,8 @@ std::string getCommand()
             case POS_LEFT: command += " left"; break;
             case POS_RIGHT: command += " right"; break;
             case POS_CENTER: command += " center"; break;
-            case POS_BOTTOM_LEFT: command += " bottom-left"; break;
-            case POS_BOTTOM_RIGHT: command += " bottom-right"; break;
+            case POS_BOTTOM_LEFT: command += " bot-left"; break;
+            case POS_BOTTOM_RIGHT: command += " bot-right"; break;
             case POS_TOP_LEFT: command += " top-left"; break;
             case POS_TOP_RIGHT: command += " top-right"; break;
         }
@@ -906,6 +921,24 @@ std::string getCommand()
         command += " --noreload";
     }
 
+    checkbutton = glade_xml_get_widget (xml, "checkbutton_taskbar");
+
+    if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (checkbutton)))
+    {
+        command += " --taskbar";
+    }
+    
+    checkbutton = glade_xml_get_widget (xml, "checkbutton_rsize");
+
+    if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (checkbutton)))
+    {
+        char text[10];
+        command += " --rsize";
+        spinbutton = glade_xml_get_widget (xml, "spinbutton_rsize");
+        sprintf(text, " %d", (int)gtk_spin_button_get_value (GTK_SPIN_BUTTON (spinbutton)));
+        command += text;
+    }
+
     checkbutton = glade_xml_get_widget (xml, "checkbutton_isize");
 
     if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (checkbutton)))
@@ -1019,12 +1052,13 @@ std::string getCommand()
         gchar text[16];
         
         gtk_color_button_get_color (GTK_COLOR_BUTTON (color), &rgb);
-		g_snprintf (text, sizeof (text), "0x%02x%02x%02x00", rgb.red >> 8, rgb.green >> 8, rgb.blue >> 8);
+        int alpha = gtk_color_button_get_alpha (GTK_COLOR_BUTTON (color));
+        g_snprintf (text, sizeof (text), "0x%02x%02x%02x%02x", alpha >> 8, rgb.red >> 8, rgb.green >> 8, rgb.blue >> 8);
         
         command += " --fc ";
         command += text;
     }
-    
+
     return command;
 }
 
@@ -1358,7 +1392,7 @@ void show_about()
         "icon", pixbuf,
         "program-name", _("wbar config"),
         "version", VERSION,
-        "copyright", _("Licence GPL - 2010"),
+        "copyright", _("License GPL - 2010"),
         "comments", _("A light and fast launch bar."),
         "website", "http://code.google.com/p/wbar/",
         "website-label", _("wbar project website"),
