@@ -3,12 +3,18 @@
 #include <iostream>
 #include "Bar.h"
 #include "i18n.h"
+#include <X11/Xatom.h>
 
 /* Posicionamiento de la ventana */
 #define MARGEN 4
 
+extern unsigned long bg_window;
+
 using namespace std;
 
+static XErrorHandler oldXHandler = (XErrorHandler) 0 ;
+static int rootErrorHandler(Display *display, XErrorEvent *theEvent);
+
 /* Bar Constructor & Destructor */
 Bar::Bar(XWin *win, string barImg, int iSize, int iDist, float zFactor,
         float jFactor, int bOrient, int bPosition, int nAnim,
@@ -57,15 +63,13 @@ Bar::~Bar()
 /*}}}*/
 
 /* Add Icon */
-void Bar::addIcon(string path, string comm)
+void Bar::addIcon(string path, string comm, unsigned long winid, 
+		    unsigned char *icondata, int iw, int ih, int refl_size)
 {
-
     icons.push_back(new Icon(path, comm,
-            (int)icon_offset + icon_size/2 + icons.size() * icon_unit, // x coord
-            y + (int)(0.125 * icon_size)));  // y coord
-
-    /* not efficient to call it here but ... user doesn't have to call it */
-    scale();
+	    (int)icon_offset + icon_size/2 + icons.size() * icon_unit, // x coord
+            y + (int)(0.125 * icon_size), // y coord
+            winid, icondata, iw, ih, refl_size));
 }
 /*}}}*/
 
@@ -202,9 +206,24 @@ void Bar::acquireBack()
     buffer = CREATE_IMAGE(t_w, t_h);
 
     /* Get background Image */
-    USE_DRAWABLE(DefaultRootWindow(window->display));
+    // with KDM->IceWM and the like, root windown may be readable by root only
+    // if no wallpaper is set. Just proceed with no background then
+    oldXHandler = XSetErrorHandler(rootErrorHandler);
+    Pixmap rootmap = GetRootPixmap(window->display);
+    // for DEs using an FM-based desktop, set it as bg source
+    if (bg_window) {
+	USE_DRAWABLE((Window)bg_window);
+    // otherwise, snapshot a backgroung pixmap set at the root window
+    } else if (rootmap != None) {
+	USE_DRAWABLE(rootmap);
+    } else {
+	// last resort: snaphsot the whole display, potentially resulting in 
+	// some artifacts from the windows above the bar
+	USE_DRAWABLE(DefaultRootWindow(window->display));
+    }
     barback = IMAGE_FROM_DRAWABLE(window->x, window->y, t_w, t_h);
     USE_DRAWABLE(window->window);
+    (void) XSetErrorHandler(oldXHandler);
 }
 /*}}}*/
 
@@ -445,6 +464,16 @@ void Bar::refresh(int mouse_x)
 }
 /*}}}*/
 
+/* Refresh the bar not having cursor focus*/
+void Bar::refreshUnfocused(int mouse_x)
+{
+    /* Relative coords */
+    mouse_x -= (int)(icon_offset + icon_size/2.0);
+    unfocus();
+    render();
+}
+/*}}}*/
+
 /* In & out of the bar */
 inline void Bar::unfocus()
 {
@@ -602,6 +631,18 @@ string Bar::iconCommand(int i_num)
     return icons[i_num]->command;
 }
 
+unsigned long Bar::iconWinId(int i_num)
+{
+    if (i_num<0 || i_num>=(int)icons.size()) return 0;
+
+    return icons[i_num]->wid;
+}
+
+int Bar::iconsShown()
+{
+    return (int)icons.size();
+}
+
 int Bar::iconIndex(int mousex)
 {
     Icon *cur_ic;
@@ -635,3 +676,13 @@ float Bar::getZoom()
 /*}}}*/
 #endif
 
+static int rootErrorHandler(Display *display, XErrorEvent *theEvent)
+{
+	if (theEvent->error_code == 9 && theEvent->request_code == 14) {
+	    std::cout << "root window is readable by root only" << std::endl;
+	    std::cout << "you may work around that by setting a wallpaper" << std::endl;
+	}
+        std::cout << "error code:" << (int) theEvent->error_code 
+                << " request code:" << (int) theEvent->request_code << std::endl;
+        return 0;
+}
