@@ -26,12 +26,13 @@ SuperBar::SuperBar(XWin *win, string barImg, string barFont, int iSize, int iDis
 	if( !(font = LOAD_FONT(barFont.c_str())) )
         {
             std::cout << _("Problem load font file.") << " " << barFont << std::endl;
-            return;
         }
-	USE_FONT(font);
-
-	imlib_get_text_size("MMMMMMMMMMMMMMMMMMMMMMMMMMMMMM", &textW, &textH);
-	font_restore = CREATE_IMAGE(textW, 2*textH);
+	else
+	{
+            USE_FONT(font);
+            imlib_get_text_size("MMMMMMMMMMMMMMMMMMMMMMMMMMMMMM", &textW, &textH);
+            font_restore = CREATE_IMAGE(textW, 2*textH);
+	}
     }
 }
 
@@ -129,7 +130,8 @@ void SuperBar::initFilters(){
 /*}}}*/
 
 /* Add Icon to the bar *//*{{{*/
-void SuperBar::addIcon(string path, string comm, string txt){
+void SuperBar::addIcon(string path, string comm, string txt, unsigned long winid,
+	unsigned char *icondata, int iw, int ih, int refl_size){
     SuperIcon *ic;
     int textW, textH;
 
@@ -138,7 +140,8 @@ void SuperBar::addIcon(string path, string comm, string txt){
 	imlib_get_text_size(txt.c_str(), &textW, &textH);
     }
 
-    icons.push_back( new SuperIcon(path, comm, txt,
+    icons.push_back( new SuperIcon(path, comm, txt, winid, icondata, iw, ih, 
+	refl_size,
 	(int)icon_offset + icon_size/2 + icons.size() * icon_unit, // x coord
 	y + (int)(0.125 * icon_size), textW, textH) ); // y coord
 
@@ -151,10 +154,13 @@ void SuperBar::addIcon(string path, string comm, string txt){
 	imlib_image_filter();
     }
 
-    scale();
 }
 /*}}}*/
 
+void SuperBar::removeIcon(){
+    icons.pop_back();
+}
+
 /* Unfocus *//*{{{*/
 inline void SuperBar::unfocus(){
     _image tBar = NULL;
