@@ -1,10 +1,12 @@
 #include "App.h"
 
-App::App(std::string icon, std::string command, std::string title)
+App::App(std::string icon, std::string command, std::string title, 
+    unsigned long winid)
 {
     this->icon = icon;
     this->command = command;
     this->title = title;
+    this->winid = winid;
 }
 
 App::~App()
@@ -26,3 +28,8 @@ std::string App::getTitle()
     return title;
 }
 
+unsigned long App::getWinid()
+{
+    return winid;
+}
+
