@@ -7,18 +7,21 @@ class App
 {
     public:
 
-        App(std::string icon, std::string command, std::string title);
+        App(std::string icon, std::string command, std::string title,
+    	    unsigned long winid);
         ~App();
 
         std::string getIconName();
         std::string getCommand();
         std::string getTitle();
+        unsigned long getWinid();
 
     private:
 
         std::string icon;
         std::string command;
         std::string title;
+        unsigned long winid;
 };
 
 #endif
